/*
 * 1.弹框
 * 2.是否为空值
 * 3.是否为数字
 * 4.
 * 5.是否是手机号码
 * 6.是否是email地址
 * 7.获取男，女字符
 * 8.卡号，账号格式化
 * 9.金额大写
 * 10.金额格式化
 * 11.手机号遮盖4-8位
 * 12.遮盖地址里的阿拉伯数字
 * 13.去掉多余的0
 * 14.格式化金额字符串，如果为0.则返回0.00
 * 15.格式化字符串，添加逗号
 * 16.格式化字符串，删除逗号
 * 17.根据指定格式，格式化日期字符串
 * 18.格式化日期字符串转换成日期类型
 * 19.是否是货币
 * 20.验证密码是否包含大小写字母和数字
 * 21.格式化账号，使其格式为4444********6788;
 * 22.自定义弹框
 */

/* JavaScript content from js/util.js in folder common */ (function($, undefined) {
	/**
	 * 字符串左补0到指定位数
	 * @param {int} width
	 * @returns {string} 
	 */
	String.prototype.leftPadZero = function( width ) {
		var pad = width - this.length;
		if ( pad > 0 ){
			return ("0".times(pad) + this); 
		}else{
			return this;	
		}
	};
	/**
	 * 连续count个当前字符串连接
	 * @param {int} count
	 * @returns {string} 
	 */
	String.prototype.times = function(count) {
    	return count < 1 ? '' : new Array(count + 1).join(this);
  	};
  	
	/**
	 * 将日期对象根据指定的格式格式化为字符串
	 * @param {string} format 日期格式
	 * @returns {string}
	 */
	Date.prototype.format = function( format ){
		if ( !format ){
			format = $.mbank.utils.DATE_FORMAT;
		}
		return format.replace(
			$.mbank.utils.REGEXP_DATE,
			function(str){
				switch ( str.toLowerCase() ){
					case 'yyyy': return this.getFullYear();
					case 'mm': return (this.getMonth() + 1).toString().leftPadZero(2);
					case 'dd': return this.getDate().toString().leftPadZero(2);
					case 'hh': return this.getHours().toString().leftPadZero(2);
					case 'mi': return this.getMinutes().toString().leftPadZero(2);
					case 'ss': return this.getSeconds().toString().leftPadZero(2);
					case 'ms': return this.getMilliseconds().toString().leftPadZero(3);
				}
			}.bind(this)
		);
	};
	
    $.mbank.utils = $.mbank.utils || {};
    
    $.extend( $.mbank.utils, {
		/*
		 * 常量
		 */
		REGEXP_MONEY : new RegExp(/^[0-9]*\.?[0-9]{0,2}$/),
		
		ACCOUNTNO_MIN : 10,			//账号最小长度
		ACCOUNTNO_MAX : 21, 		//账号最大长度
		CREDITACARDNO_MIN : 16,		//信用卡账号最小长度
		CREDITACARDNO_MAX : 16, 	//信用卡账号最大长度
		CURRENCY_MAX : 18,			//金额最大长度
		CURRENCY_NO_DOT : false,	//后台存储的金额是否没有小数点
		

		failStop : false,			// 是否在第一次校验失败后就停止校验
		countByChar : true,
		tipContainer : null		//tipContainer
	});
	
    $.extend($.mbank.utils, {
    	
		REGEXP_COMMA : new RegExp('\,',["g"]),
		REGEXP_DATE : new RegExp(/(yyyy|mm|dd|hh|mi|ss|ms)/gi),
		DATE_FORMAT : "yyyymmdd",
		DATE_FORMAT_DISPLAY : "yyyy年mm月dd日",
		DATE_FORMAT_SHORT : "yyyy-mm-dd",
        isNoValue: function(str) {
            if (str == null || str == "") {
                return true;
            }
            return false;
        },
        checkNum: function(str) {
            return /^[0-9]+$/.test(str);
        },
        
        //校验取款密码，必须6位，只能为数字 
        checkTransactionPassword: function(str) {
            return str.length == 6 && /^[0-9]+$/.test(str);
        },
        //校验昵称，6-12位（包含数字和小写字母，允许纯字母及字母与数字组合，但不能纯数字)
        checkUsername: function(str) {
            return str.length >= 6 && str.length <= 12 && /^[a-z]+[0-9]*$/.test(str);
        },
        //6-20位手机银行登录密码
        checkLoginPassword: function(str) {
            return str.length >= 6 && str.length <= 20 && /^[a-z]+[0-9]*$/.test(str);
        },
        
        isIdValidStr: function(str) {
            var tel = /^[a-zA-Z0-9\_\-\(\)]+$/;
            return tel.test(str.trim(str));
        },
        //手机号码校验
        isMobile: function(value) {
            var length = value.length;
            return length == 11 && /^[0-9]+$/.test(value);
        },
        //是否合法借记卡号
        isDebtCard: function(value) {
            var length = value.length;
            return length >= 15 && length <= 22 && /^[0-9\-]+$/.test(value);
        },
        isEmail: function(value) {
            var reg = /^([a-zA-Z0-9_\.\-])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
            return reg.test(value.trim(value));
        },
        
        /*
         * @desc:获取男女字符
         * @par:M为男，F为女
         */
        getSexName: function(type) {
            var map = {
                "M": "男",
                "F": "女"
            };
            return map[type];
        },
        
        /*
         * @desc：账号格式化
         * @par：
         * accountNo：预格式化的账号或卡号，
         * hide：hide参数为"hide"时，获取隐藏的账号
         * start，end，在hide为"hide"时，会读取start和end 参数，开始和结束隐藏字符*的位置，默认为倒数第8位到倒数第4位
         * @return：
         * 返回格式化后的字符串
         */
        formatAccountNo: function(accountNo, hide, start, end) {
            var formatStr = "";
            start = start || accountNo.length - 8;
            end = end || accountNo.length - 5;
            $.each(accountNo, function(index, element) {
                if (hide == "hide") {
                    if (index >= start && index <= end) {
                        element = "*";
                    }
                }
                if (index != 0 && index % 4 == 0) {
                    element = " " + element;
                }
                formatStr = formatStr + element;
            });
            return formatStr;
        },
        
        /*
         * @desc：金额大写
         * @par：
         * num：预格式化的金额数字
         * @retur：
         * 返回对应金额的大写的字符串
         */
        numToChinese: function(num) {
            if (!/^\d*(\.\d*)?$/.test(num)) {
                alert("Number is wrong!");
                return "Number is wrong!";
            }
            var AA = new Array("零", "壹", "贰", "叁", "肆", "伍", "陆", "柒", "捌", "玖");
            var BB = new Array("", "拾", "佰", "仟", "萬", "億", "点", "");
            var a = ("" + num).replace(/(^0*)/g, "").split("."),
                k = 0,
                re = "";
            for (var i = a[0].length - 1; i >= 0; i--) {
                switch (k) {
                    case 0:
                        re = BB[7] + re;
                        break;
                    case 4:
                        if (!new RegExp("0{4}\\d{" + (a[0].length - i - 1) + "}$").test(a[0]))
                            re = BB[4] + re;
                        break;
                    case 8:
                        re = BB[5] + re;
                        BB[7] = BB[5];
                        k = 0;
                        break;
                }
                if (k % 4 == 2 && a[0].charAt(i + 2) != 0 && a[0].charAt(i + 1) == 0) re = AA[0] + re;
                if (a[0].charAt(i) != 0) re = AA[a[0].charAt(i)] + BB[k % 4] + re;
                k++;
            }
            if (a.length > 1) //加上小数部分(如果有小数部分)
            {
                re += BB[6];
                for (var i = 0; i < a[1].length; i++) re += AA[a[1].charAt(i)];
            }
            return re;
        },
        
        /*
         * @desc：对数字进行金额格式化
         * @par：
         * number：预格式化的金额数字
         * places:小数点后位数，必填，一般填2即可
         * symbol:货币符号，选填，默认人民币符号，可置为空(即不要货币符号)
         * thousand:千位符，选填
         * decimal:小数点，选填
         * @retur：
         * 返回数字对应的金额字符串
         */
        formatMoney: function (number, places, symbol, thousand, decimal) {
            number = number || 0;
            places = !isNaN(places = Math.abs(places)) ? places : 2;
            symbol = symbol !== undefined ? symbol : "¥";
            thousand = thousand || ",";
            decimal = decimal || ".";
            var negative = number < 0 ? "-" : "",
            	//取整
                i = parseInt(number = Math.abs(+number || 0).toFixed(places), 10) + "",
                //计算出千位
                j = (j = i.length) > 3 ? j % 3 : 0;
            return symbol + negative + (j ? i.substr(0, j) + thousand : "") 
            		+ i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + thousand) 
            		+ (places ? decimal + Math.abs(number - i).toFixed(places).slice(2) : "");
        },
        
        
        /*
         * @desc：金额格式化
         * @par：
         * money：将格式化的字符串，若money中有‘，’，返回去掉‘，’后的字符串，反之将以默认为3位格式化money字符串
         * size：分割字符串时，size可是设定位数，默认为3
         * @return：
         * 返回格式化后的字符串
         */
        moneyFormat: function(money, size) {
            var formatStr = "";
            if (money.indexOf(",") == -1) {
                var k = 0;
                var sp = size || 3;
                for (var i = money.length; i > 0; i--,k++) {
                    if ((k % sp == 0) && (k != 0)) {
                        formatStr = money[i - 1] + "," + formatStr;
                    } else formatStr = money[i - 1] + formatStr;
                }
                return formatStr;
            } else {
                $.each(money, function(index, element) {
                    if (element == ',' || element == ' ') {
                        return true;
                    }
                    formatStr = formatStr + element;
                });
                return formatStr;
            }
        },
        /*
         * @desc：手机号遮盖4-8位
         * @par：
         * accountNo：预格式化的手机号，
         * start，end， ，会读取start和end 参数，开始和结束隐藏字符*的位置，默认为倒数第8位到倒数第4位
         * @return：
         * 返回格式化后的字符串
         */
        formatPhoneNoHide: function(phoneNo,start, end) {
            var formatStr = "";
            start = start || phoneNo.length - 7;
            end = end || phoneNo.length - 3;
            $.each(phoneNo, function(index, element) {
                    if (index >= start && index <= end) {
                        element = "*";
                    }
                formatStr = formatStr + element;
            });
            return formatStr;
        },        
        /*
         * @desc：遮盖地址里的阿拉伯数字
         * @par：
         * address：预格式化的地址，
         * @return：
         * 返回格式化后的字符串
         */
        formatAddress: function(address ) {
            var formatStr = "";
 
            $.each(address, function(index, element) {
            	
                if (/^\d*(\.\d*)?$/.test(element)) {
                    
                	 element = "*";
                }
 
                formatStr = formatStr + element;
            });
            return formatStr;
        },
        /*
         * @desc：格式化金额字符串
         * @par：
         * address：预格式化的地址，
         * @return：
         * 返回格式化后的字符串
         */            
		prepareCashString: function( cash, dot, digits ) {
			if (cash == undefined) cash = '0';
			if (dot == undefined) dot = true;
			if (digits == undefined) digits = 2;
			
			if (typeof cash !== 'string') {
				cash = cash.toString();
			}
			cash = $.mbank.utils.removeComma(cash);
			
			//TODO检查是否金额
			// 处理包含正负符号的情况
			var prefix = cash.charAt(0);
			if ( prefix == "-" || prefix == "+" ){
				return prefix + $.mbank.utils.prepareCashString( cash.substr(1), dot, digits );
			}
			
			if (cash.indexOf('.') != -1) {
				dot = true;	//如果输入串本身包含小数点，则忽略dot参数的设置，认为是真实金额大小
			}
			var integerCash, decimalCash;
			if (!dot) {
				if (cash.length <= digits) {
					cash = cash.leftPadZero(digits+1);
				}
				integerCash = cash.substring(0, cash.length - digits);
				decimalCash = cash.substring(cash.length - digits);
			} 
			else {
				var dotPos = cash.indexOf('.');
				if (dotPos != -1) {
					integerCash = cash.substring(0, dotPos);
					decimalCash = cash.substring(dotPos + 1);
				} 
				else {
					integerCash = cash;
					decimalCash = '';
				}
				if (integerCash.length == 0)
					integerCash = '0';
				if (decimalCash.length < digits) {
					decimalCash += '0'.times(digits - decimalCash.length);
				} 
				else {
					decimalCash = decimalCash.substring(0, digits);		//TODO 考虑四舍五入
				}
			}
			
			//去掉头部多余的0
			while (integerCash.charAt(0) == '0' && integerCash.length>1) {
				integerCash = integerCash.substring(1);
			}
			cash = integerCash + '.' + decimalCash;
			
			return cash;
		},
        /*
         * @desc：格式化，如果为0.则返回0.00
         * @par：
         * address：预格式化的地址，
         * @return：
         * 返回格式化后的字符串
         */        
    	toCashWithCommaReturn0: function( cash, dot, digits ) {
    		if (cash != null && typeof cash !== "string") {
    			cash = cash.toString();
    		}
    		if(cash == '' || cash == null){
    			return '';
    		}
    		else {
    			var temp = $.mbank.utils.prepareCashString( cash, dot, digits );
    			
    			var dotPos = temp.indexOf('.');
    			var integerCash = temp.substring(0, dotPos);
    			var decimalCash = temp.substring(dotPos + 1);
    		
    			// 处理包含正负符号的情况
    			var prefix = integerCash.charAt(0);
    			if ( prefix == "-" || prefix == "+" ) {
    				temp = prefix + $.mbank.utils.addComma(integerCash.substring(1)) + '.' + decimalCash;
    			} 
    			else {
    				temp = $.mbank.utils.addComma(integerCash) + '.' + decimalCash;
    			}
    			return temp;
    		}
    	},
        /*
         * @desc：格式化字符串，添加逗号
         * @par：
         * str：预格式化的字符串，
         * @return：
         * 返回格式化后的字符串
         */     	
		addComma: function(str) {
			if (str.length > 3) {
				var mod = str.length % 3;
				var output = (mod > 0 ? (str.substring(0,mod)) : '');
				for (var i=0 ; i < Math.floor(str.length / 3); i++) {
					if ((mod == 0) && (i == 0))
						output += str.substring(mod+ 3 * i, mod + 3 * i + 3);
					else
						output += ',' + str.substring(mod + 3 * i, mod + 3 * i + 3);
				}
				return (output);
			}
			else 
				return str;
		},
        /*
         * @desc：格式化字符串，删除逗号
         * @par：
         * str：预格式化的字符串，
         * @return：
         * 返回格式化后的字符串
         */  
		removeComma: function(str){
			return str.replace($.mbank.utils.REGEXP_COMMA,'');
		},
        /*
         * @desc：格式化日期字符串
         * @par：
         * date：预格式化的日期字符串，
         * outFormat：要格式化成的格式
         * @return：
         * 返回格式化后的字符串
         */  		
		formatDate: function(date, outFormat ) {
			if(date == '' || date == null){
				return '';
			}
			else {
				var parsedDate = $.mbank.utils.parseDate( date, $.mbank.utils.DATE_FORMAT );
				if( outFormat && typeof outFormat === "string" ) {
					return parsedDate.format( outFormat );
				}
				else {
					return parsedDate.format( $.mbank.utils.DATE_FORMAT_SHORT );	
				}
			}
		},
		
		/**
		 * @desc：格式化日期字符串转换成日期类型
		 * @param dateString
		 * @param format
		 * @returns {Date}
		 */
		parseDate: function( dateString, format ){
			var year=2000,month=0,day=1,hour=0,minute=0,second=0;
			format = format ||  $.mbank.format.DATE_FORMAT;
			var matchArray = format.match( $.mbank.utils.REGEXP_DATE );
			for (var i = 0; i < matchArray.length; i++ ) {
				var postion =format.indexOf( matchArray[i] );
				switch (matchArray[i]) {
					case "yyyy":{
						year = parseInt( dateString.substr(postion,4), 10 );
						break;
					}
					case "mm":{
						month = parseInt( dateString.substr(postion,2), 10 )-1;
						break;
					}
					case "dd":{
						day = parseInt( dateString.substr(postion,2), 10 );
						break;
					}
					case "hh":{
						hour = parseInt( dateString.substr(postion,2), 10 );
						break;
					}
					case "mi":{
						minute = parseInt( dateString.substr(postion,2), 10 );
						break;
					}
					case "ss":{
						second = parseInt( dateString.substr(postion,2), 10 );
						break;
					}
				}
			}
			return new Date(year,month,day,hour,minute,second);
		},
		/**
		 * 计算日期相隔天数
		 * @param {DateString} startDate	yyyy-mm-dd
		 * @param {DateString} endDate		yyyy-mm-dd
		 */
		getDateDiff:function(startDate, endDate){
			var startTime = new Date(Date.parse(startDate.replace(/-/g, "/"))).getTime();
			var endTime = new Date(Date.parse(endDate.replace(/-/g, "/"))).getTime();
			var dates = Math.abs((startTime - endTime)) / (1000 * 60 * 60 * 24);
			return dates;
		},
		/**
		 * 去除逗号验证是否是货币
		 * @param value
		 * @returns
		 */
		currency:function(value){

            var valueWithoutDot = $.mbank.utils.removeComma(value);
            if ( valueWithoutDot.length > $.mbank.utils.CURRENCY_MAX ){
                return false;
            }
            if(valueWithoutDot == 0)
            	return false;
            return ( $.mbank.utils.isMoney( valueWithoutDot ) );
		},
		/**
		* 检查字符串是否为合法的金额
		* @param {string} s 字符串
		* @returns {boolean} 是否为合法金额
		*/
		isMoney: function(s) {
		    return ( $.mbank.utils.REGEXP_MONEY.test(s) );
		},
		/**
		 * 验证密码是否包含大小写字母和数字
		 * @param str
		 * @returns
		 */
		checkCenterPassword:function(str){
			var ls = 0; 
			if(str.match(/([a-z])+/)){   
			    ls++;   
			}  
			if(str.match(/([0-9])+/)){   
			    ls++;   
			} 
			if(str.match(/([A-Z])+/)){   
			    ls++;   
			}
			if(str.match(/[^a-zA-Z0-9]+/)){   
			    ls++;   
			}	
			return ls; 
		},		
		//格式化账号，使其格式为4444********6788;
		dealAccountNoHide: function( cash, dot, digits ) {
			if (cash != null && typeof cash !== "string") {
				cash = cash.toString();
			}
			if(cash == '' || cash == null||cash==undefined){
				return '';
			}
			else {
				var temp;
				cash = $.trim(cash);
				if(cash.length>=12){
					temp = cash.substring(0,4)+"********"+cash.substring(cash.length-4,cash.length);
				}else{
					temp = cash;
				}
			}
			return temp;
		},
        bankAlert: function(text,title,color) {
        	title=title||'消息提示';
        	color=color||'red';
        	$.magnificPopup.open({
        		  items: {
        		    src: ''
        			    +'<div  data-overlay-theme="a" class="ui-content ui-popup ui-body-a ui-overlay-shadow ui-corner-all ui-body-inherit">'
        		          +'<h2>'+title+'</h2>'
        		          +'<p class="topic"><strong style="color:'+color+'">'+text+'</strong></p>'
        		          +'<div class="ui-grid-solo bg-white">'
        		          +'<div class="ui-block-a">'
        		          +'<a href="javascript:void(0);" data-role="button" data-shadow="false" class="confirm-pay ui-link ui-btn ui-corner-all" id="messageBtn">确定</a>'
        		          +'</div></div>',
        		    type: 'inline',
        		    
        		  },
        		  modal:true
        		});
        }
		
        
    });
})(jQuery)